#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import time

from starlette.websockets import WebSocketDisconnect

if __name__ == '__main__':
    from fastapi import FastAPI, WebSocket
    import uvicorn

    app = FastAPI()


    @app.get('/users')
    async def application():
        time.sleep(0.5)
        return {'song': 'Despacito', 'artist': 'Luis Fonsi'}


    @app.websocket('/ws')
    async def websocket_endpoint(websocket: WebSocket):
        await websocket.accept()
        try:
            while True:
                msg = await websocket.receive_text()
                if msg.lower() == 'close':
                    await websocket.close()
                    break
                else:
                    await websocket.send_text('Pong')
        except WebSocketDisconnect:
            ...
        return 'ok'

    uvicorn.run(app, host='0.0.0.0', port=9091)
